summaryrefslogtreecommitdiff
path: root/include/internal/database/copy.h
diff options
context:
space:
mode:
authorCedric Nugteren <web@cedricnugteren.nl>2016-01-30 11:43:21 +0100
committerCedric Nugteren <web@cedricnugteren.nl>2016-01-30 11:43:21 +0100
commit276e772a2c672ad868ba57e06d55e4991c793207 (patch)
tree015c32f78022e65403dc207c80d2b52458363f68 /include/internal/database/copy.h
parent76c91480303dd398b4ff5953a833e493b1409630 (diff)
Added first auto-generated database headers from the Python database; only K40 and Iris supported now
Diffstat (limited to 'include/internal/database/copy.h')
-rw-r--r--include/internal/database/copy.h106
1 files changed, 38 insertions, 68 deletions
diff --git a/include/internal/database/copy.h b/include/internal/database/copy.h
index 541a352b..3bd85fa6 100644
--- a/include/internal/database/copy.h
+++ b/include/internal/database/copy.h
@@ -5,9 +5,9 @@
// width of 100 characters per line.
//
// Author(s):
-// Cedric Nugteren <www.cedricnugteren.nl>
+// Database generator <database.py>
//
-// This file populates the database with best-found tuning parameters for the Copy kernels.
+// This file populates the database with best-found tuning parameters for the 'Copy' kernels.
//
// =================================================================================================
@@ -16,26 +16,21 @@ namespace clblast {
const Database::DatabaseEntry Database::CopySingle = {
"Copy", Precision::kSingle, {
- { // NVIDIA GPUs
- kDeviceTypeGPU, kDeviceVendorNVIDIA, {
- { "GeForce GTX 480", { {"COPY_DIMX",32}, {"COPY_DIMY",8}, {"COPY_WPT",1}, {"COPY_VW",2} } },
- { "Tesla K20m", { {"COPY_DIMX",8}, {"COPY_DIMY",16}, {"COPY_WPT",2}, {"COPY_VW",4} } },
- { "Tesla K40m", { {"COPY_DIMX",16}, {"COPY_DIMY",16}, {"COPY_WPT",4}, {"COPY_VW",4} } },
- }
- },
- { // AMD GPUs
- kDeviceTypeGPU, kDeviceVendorAMD, {
- { "Tahiti", { {"COPY_DIMX",16}, {"COPY_DIMY",8}, {"COPY_WPT",4}, {"COPY_VW",2} } },
+ { // Intel GPUs
+ kDeviceTypeGPU, "Intel", {
+ { "Iris", { {"COPY_DIMX",16}, {"COPY_DIMY",8}, {"COPY_VW",1}, {"COPY_WPT",2} } },
+ { "default", { {"COPY_DIMX",16}, {"COPY_DIMY",8}, {"COPY_VW",1}, {"COPY_WPT",2} } },
}
},
- { // Intel GPUs
- kDeviceTypeGPU, kDeviceVendorIntel, {
- { "Iris", { {"COPY_DIMX",32}, {"COPY_DIMY",8}, {"COPY_WPT",1}, {"COPY_VW",4} } },
+ { // NVIDIA Corporation GPUs
+ kDeviceTypeGPU, "NVIDIA Corporation", {
+ { "Tesla K40m", { {"COPY_DIMX",8}, {"COPY_DIMY",8}, {"COPY_VW",4}, {"COPY_WPT",2} } },
+ { "default", { {"COPY_DIMX",8}, {"COPY_DIMY",8}, {"COPY_VW",4}, {"COPY_WPT",2} } },
}
},
{ // Default
- kDeviceTypeAll, kDeviceVendorAll, {
- { kDefaultDevice, { {"COPY_DIMX",8}, {"COPY_DIMY",8}, {"COPY_WPT",1}, {"COPY_VW",1} } },
+ kDeviceTypeAll, "default", {
+ { "default", { {"COPY_DIMX",8}, {"COPY_DIMY",8}, {"COPY_VW",1}, {"COPY_WPT",2} } },
}
},
}
@@ -43,27 +38,23 @@ const Database::DatabaseEntry Database::CopySingle = {
// =================================================================================================
-const Database::DatabaseEntry Database::CopyDouble = {
- "Copy", Precision::kDouble, {
- { // NVIDIA GPUs
- kDeviceTypeGPU, kDeviceVendorNVIDIA, {
- { "GeForce GTX 480", { {"COPY_DIMX",16}, {"COPY_DIMY",8}, {"COPY_WPT",1}, {"COPY_VW",1} } },
- { "Tesla K20m", { {"COPY_DIMX",16}, {"COPY_DIMY",8}, {"COPY_WPT",1}, {"COPY_VW",2} } },
- { "Tesla K40m", { {"COPY_DIMX",32}, {"COPY_DIMY",8}, {"COPY_WPT",1}, {"COPY_VW",2} } },
- }
- },
- { // AMD GPUs
- kDeviceTypeGPU, kDeviceVendorAMD, {
- { "Tahiti", { {"COPY_DIMX",16}, {"COPY_DIMY",8}, {"COPY_WPT",2}, {"COPY_VW",4} } },
+const Database::DatabaseEntry Database::CopyComplexSingle = {
+ "Copy", Precision::kComplexSingle, {
+ { // Intel GPUs
+ kDeviceTypeGPU, "Intel", {
+ { "Iris", { {"COPY_DIMX",16}, {"COPY_DIMY",8}, {"COPY_VW",1}, {"COPY_WPT",2} } },
+ { "default", { {"COPY_DIMX",16}, {"COPY_DIMY",8}, {"COPY_VW",1}, {"COPY_WPT",2} } },
}
},
- { // Intel GPUs
- kDeviceTypeGPU, kDeviceVendorIntel, {
+ { // NVIDIA Corporation GPUs
+ kDeviceTypeGPU, "NVIDIA Corporation", {
+ { "Tesla K40m", { {"COPY_DIMX",16}, {"COPY_DIMY",8}, {"COPY_VW",1}, {"COPY_WPT",1} } },
+ { "default", { {"COPY_DIMX",16}, {"COPY_DIMY",8}, {"COPY_VW",1}, {"COPY_WPT",1} } },
}
},
{ // Default
- kDeviceTypeAll, kDeviceVendorAll, {
- { kDefaultDevice, { {"COPY_DIMX",8}, {"COPY_DIMY",8}, {"COPY_WPT",1}, {"COPY_VW",1} } },
+ kDeviceTypeAll, "default", {
+ { "default", { {"COPY_DIMX",16}, {"COPY_DIMY",8}, {"COPY_VW",1}, {"COPY_WPT",1} } },
}
},
}
@@ -71,28 +62,17 @@ const Database::DatabaseEntry Database::CopyDouble = {
// =================================================================================================
-const Database::DatabaseEntry Database::CopyComplexSingle = {
- "Copy", Precision::kComplexSingle, {
- { // NVIDIA GPUs
- kDeviceTypeGPU, kDeviceVendorNVIDIA, {
- { "GeForce GTX 480", { {"COPY_DIMX",16}, {"COPY_DIMY",16}, {"COPY_WPT",1}, {"COPY_VW",1} } },
- { "Tesla K20m", { {"COPY_DIMX",32}, {"COPY_DIMY",8}, {"COPY_WPT",2}, {"COPY_VW",1} } },
- { "Tesla K40m", { {"COPY_DIMX",32}, {"COPY_DIMY",8}, {"COPY_WPT",1}, {"COPY_VW",1} } },
- }
- },
- { // AMD GPUs
- kDeviceTypeGPU, kDeviceVendorAMD, {
- { "Tahiti", { {"COPY_DIMX",32}, {"COPY_DIMY",8}, {"COPY_WPT",1}, {"COPY_VW",1} } },
- }
- },
- { // Intel GPUs
- kDeviceTypeGPU, kDeviceVendorIntel, {
- { "Iris", { {"COPY_DIMX",32}, {"COPY_DIMY",8}, {"COPY_WPT",1}, {"COPY_VW",1} } },
+const Database::DatabaseEntry Database::CopyDouble = {
+ "Copy", Precision::kDouble, {
+ { // NVIDIA Corporation GPUs
+ kDeviceTypeGPU, "NVIDIA Corporation", {
+ { "Tesla K40m", { {"COPY_DIMX",8}, {"COPY_DIMY",8}, {"COPY_VW",2}, {"COPY_WPT",2} } },
+ { "default", { {"COPY_DIMX",8}, {"COPY_DIMY",8}, {"COPY_VW",2}, {"COPY_WPT",2} } },
}
},
{ // Default
- kDeviceTypeAll, kDeviceVendorAll, {
- { kDefaultDevice, { {"COPY_DIMX",8}, {"COPY_DIMY",8}, {"COPY_WPT",1}, {"COPY_VW",1} } },
+ kDeviceTypeAll, "default", {
+ { "default", { {"COPY_DIMX",8}, {"COPY_DIMY",8}, {"COPY_VW",2}, {"COPY_WPT",2} } },
}
},
}
@@ -102,25 +82,15 @@ const Database::DatabaseEntry Database::CopyComplexSingle = {
const Database::DatabaseEntry Database::CopyComplexDouble = {
"Copy", Precision::kComplexDouble, {
- { // NVIDIA GPUs
- kDeviceTypeGPU, kDeviceVendorNVIDIA, {
- { "GeForce GTX 480", { {"COPY_DIMX",16}, {"COPY_DIMY",8}, {"COPY_WPT",1}, {"COPY_VW",1} } },
- { "Tesla K20m", { {"COPY_DIMX",8}, {"COPY_DIMY",32}, {"COPY_WPT",1}, {"COPY_VW",1} } },
- { "Tesla K40m", { {"COPY_DIMX",8}, {"COPY_DIMY",8}, {"COPY_WPT",1}, {"COPY_VW",1} } },
- }
- },
- { // AMD GPUs
- kDeviceTypeGPU, kDeviceVendorAMD, {
- { "Tahiti", { {"COPY_DIMX",8}, {"COPY_DIMY",32}, {"COPY_WPT",4}, {"COPY_VW",2} } },
- }
- },
- { // Intel GPUs
- kDeviceTypeGPU, kDeviceVendorIntel, {
+ { // NVIDIA Corporation GPUs
+ kDeviceTypeGPU, "NVIDIA Corporation", {
+ { "Tesla K40m", { {"COPY_DIMX",8}, {"COPY_DIMY",8}, {"COPY_VW",1}, {"COPY_WPT",1} } },
+ { "default", { {"COPY_DIMX",8}, {"COPY_DIMY",8}, {"COPY_VW",1}, {"COPY_WPT",1} } },
}
},
{ // Default
- kDeviceTypeAll, kDeviceVendorAll, {
- { kDefaultDevice, { {"COPY_DIMX",8}, {"COPY_DIMY",8}, {"COPY_WPT",1}, {"COPY_VW",1} } },
+ kDeviceTypeAll, "default", {
+ { "default", { {"COPY_DIMX",8}, {"COPY_DIMY",8}, {"COPY_VW",1}, {"COPY_WPT",1} } },
}
},
}